Runtime

Struct Runtime 

pub struct Runtime<'a, D, C>
where D: DrawTarget<Color = C> + RenderFB + OriginDimensions, C: RgbColor + FromRGB,
{ /* private fields */ }

Implementations

Source

impl<'a, D, C> Runtime<'a, D, C>
where D: DrawTarget<Color = C> + RenderFB + OriginDimensions, C: RgbColor + FromRGB,

pub fn new(config: RuntimeConfig<'a, D, C>) -> Result<Self, Error>

Create a new runtime with the wasm module loaded and instantiated.

pub fn set_render_every(&mut self, render_every: u8)

Set how often render should be called relative to update.

Exposed excludively for firefly-test to combat FPS auto-adjustment.

pub fn display_mut(&mut self) -> &mut D

pub fn run(self) -> Result<(), Error>

Run the app until exited or an error occurs.

pub fn start(&mut self) -> Result<(), Error>

Call init functions in the module.

pub fn update(&mut self) -> Result<bool, Error>

Update the app state and flush the frame on the display.

If there is not enough time passed since the last update, the update will be delayed to keep the expected frame rate.

pub fn finalize(self) -> Result<RuntimeConfig<'a, D, C>, Error>

Gracefully stop the runtime.

  1. Calls before_exit callback.
  2. Persists stash and update stats.
  3. Releases Device ownership.
  4. Tells which app to run next.
pub fn device_mut(&mut self) -> &mut DeviceImpl<'a>