pub struct Runtime<'a, D, C>{ /* private fields */ }Implementations
Sourceimpl<'a, D, C> Runtime<'a, D, C>
impl<'a, D, C> Runtime<'a, D, C>
Sourcepub fn new(config: RuntimeConfig<'a, D, C>) -> Result<Self, Error>
pub fn new(config: RuntimeConfig<'a, D, C>) -> Result<Self, Error>
Create a new runtime with the wasm module loaded and instantiated.
Sourcepub fn set_render_every(&mut self, render_every: u8)
pub fn set_render_every(&mut self, render_every: u8)
Set how often render should be called relative to update.
Exposed excludively for firefly-test to combat FPS auto-adjustment.
pub fn display_mut(&mut self) -> &mut D
Sourcepub fn update(&mut self) -> Result<bool, Error>
pub fn update(&mut self) -> Result<bool, Error>
Update the app state and flush the frame on the display.
If there is not enough time passed since the last update, the update will be delayed to keep the expected frame rate.
Sourcepub fn finalize(self) -> Result<RuntimeConfig<'a, D, C>, Error>
pub fn finalize(self) -> Result<RuntimeConfig<'a, D, C>, Error>
Gracefully stop the runtime.
- Calls
before_exitcallback. - Persists stash and update stats.
- Releases
Deviceownership. - Tells which app to run next.
pub fn device_mut(&mut self) -> &mut DeviceImpl<'a>